<?php

/**
 * @file
 * Contains CRUD operations for SimpleCrop module.
 */

/**
 * Create/update image crop data.
 *
 * @param $uri
 *   URI of image.
 *
 * @param $data
 *   Data that contains crop area.
 */
function simplecrop_crop_save($uri, $data) {
  db_merge('simplecrop')
    ->key(array('uri' => $uri))
    ->fields(array('data' => serialize($data)))
    ->execute();
}

/**
 * Load crop for image by uri.
 *
 * @param $uri
 *   URI of image.
 *
 * @param bool $reset
 *   Indicates whether to reset static cache.
 *
 * @return mixed
 */
function simplecrop_crop_load($uri, $reset = FALSE) {

  $cache = &drupal_static(__FUNCTION__);
  if (isset($cache[$uri]) && !$reset) {
    return $cache[$uri];
  }

  $cache[$uri] = db_select('simplecrop')
    ->fields('simplecrop')
    ->condition('uri', $uri)
    ->execute()
    ->fetchObject();

  if (!empty($cache[$uri])) {
    $cache[$uri]->data = unserialize($cache[$uri]->data);
  }

  return $cache[$uri];
}

/**
 * Delete image crop by file ID.
 *
 * @param $uri
 *   URI of image.
 */
function simplecrop_crop_delete($uri) {
  db_delete('simplecrop')
    ->condition('uri', $uri)
    ->execute();
}
